summaryrefslogtreecommitdiff
path: root/example_create.sh
diff options
context:
space:
mode:
Diffstat (limited to 'example_create.sh')
-rwxr-xr-xexample_create.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/example_create.sh b/example_create.sh
index c9a957a..e1b79f4 100755
--- a/example_create.sh
+++ b/example_create.sh
@@ -3,7 +3,7 @@
# - Makes static pages for each repository directory.
#
# NOTE, things to do manually (once) before running this script:
# - copy style.css, logo.png and favicon.ico manually, a style.css example
# is included.
#
# - write clone url, for example "git://git.codemadness.org/dir" to the "url"
@@ -24,7 +24,7 @@ mkdir -p "$webdir" || exit 1
# set assets if not already there
ln -s "$defaultdir/style.css" "$webdir/style.css" 2> /dev/null
-ln -s "$defaultdir/logo.png" "$webdir/logo.png" 2> /dev/null
+ln -s "$defaultdir/logo.svg" "$webdir/logo.svg" 2> /dev/null
ln -s "$defaultdir/favicon.ico" "$webdir/favicon.ico" 2> /dev/null
# clean
@@ -3,7 +3,7 @@
#
# NOTE, things to do manually (once) before running this script:
-# - copy style.css, logo.png and favicon.ico manually, a style.css example
+# - copy style.css, logo.svg and favicon.ico manually, a style.css example
# is included.
#